"""This package contains various modules that should be generic and reused in
web application, specially CRM-like applications."""

from .util import url_for

__all__ = ["url_for"]
